==> infrahub_server-1.2.0.tar.gz: infrahub_server-1.2.0/backend/infrahub/validators/events.py <==
from infrahub_sdk.protocols import CoreValidator

from infrahub.context import InfrahubContext
from infrahub.events.models import EventMeta
from infrahub.events.validator_action import ValidatorFailedEvent, ValidatorPassedEvent, ValidatorStartedEvent
from infrahub.services import InfrahubServices


async def send_failed_validator(
    service: InfrahubServices, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorFailedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await service.event.send(event=event)


async def send_passed_validator(
    service: InfrahubServices, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorPassedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await service.event.send(event=event)


async def send_start_validator(
    service: InfrahubServices, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorStartedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await service.event.send(event=event)

==> infrahub_server-1.4.2.tar.gz: infrahub_server-1.4.2/backend/infrahub/validators/events.py <==
from infrahub_sdk.protocols import CoreValidator

from infrahub.context import InfrahubContext
from infrahub.events.models import EventMeta
from infrahub.events.validator_action import ValidatorFailedEvent, ValidatorPassedEvent, ValidatorStartedEvent
from infrahub.services.adapters.event import InfrahubEventService


async def send_failed_validator(
    event_service: InfrahubEventService, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorFailedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await event_service.send(event=event)


async def send_passed_validator(
    event_service: InfrahubEventService, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorPassedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await event_service.send(event=event)


async def send_start_validator(
    event_service: InfrahubEventService, validator: CoreValidator, proposed_change_id: str, context: InfrahubContext
) -> None:
    event = ValidatorStartedEvent(
        node_id=validator.id,
        kind=validator.get_kind(),
        proposed_change_id=proposed_change_id,
        meta=EventMeta.from_context(context=context),
    )
    await event_service.send(event=event)
